@@ -12,9 +12,16 @@
  */
 
 /*
- * $Id: binkd.c,v 2.112 2012/05/14 06:14:57 gul Exp $
+ * $Id: binkd.c,v 2.112.2.2 2014/08/20 06:12:37 gul Exp $
  *
  * $Log: binkd.c,v $
+ * Revision 2.112.2.2  2014/08/20 06:12:37  gul
+ * Fixed 100% cpu load if called with poll flag,
+ * backport many fixes related to compilation on win32 and os/2.
+ *
+ * Revision 2.112.2.1  2014/08/09 15:17:41  gul
+ * Large files support on Win32 (backport from develop branch)
+ *
  * Revision 2.112  2012/05/14 06:14:57  gul
  * More safe signal handling
  *
@@ -421,6 +428,7 @@
 #include <sys/wait.h>
 #endif
 
+#include "sys.h"
 #include "readcfg.h"
 #include "common.h"
 #include "server.h"
@@ -453,7 +461,6 @@
 #endif
 
 #ifdef WIN32
-#include <windows.h>
 #include "nt/service.h"
 #include "nt/w32tools.h"
 #ifdef BINKD9X
