@@ -12,9 +12,19 @@
  */
 
 /*
- * $Id: client.c,v 2.82.2.2 2012/09/24 00:39:09 gul Exp $
+ * $Id: client.c,v 2.82.2.5 2014/08/20 06:12:37 gul Exp $
  *
  * $Log: client.c,v $
+ * Revision 2.82.2.5  2014/08/20 06:12:37  gul
+ * Fixed 100% cpu load if called with poll flag,
+ * backport many fixes related to compilation on win32 and os/2.
+ *
+ * Revision 2.82.2.4  2014/08/09 15:17:42  gul
+ * Large files support on Win32 (backport from develop branch)
+ *
+ * Revision 2.82.2.3  2014/08/03 21:23:56  gul
+ * Fix in clientmgr scheduler
+ *
  * Revision 2.82.2.2  2012/09/24 00:39:09  gul
  * call freeaddrinfo() from client in fork version
  *
@@ -333,6 +343,7 @@
 #include <sys/wait.h>
 #endif
 
+#include "sys.h"
 #include "readcfg.h"
 #include "client.h"
 #include "ftnnode.h"
@@ -370,17 +381,8 @@ static void alrm (int signo)
 
 #if defined(HAVE_THREADS)
 #define SLEEP(x) WaitSem(&wakecmgr, x)
-#elif defined(VOID_SLEEP) || !defined(HAVE_FORK)
-#define SLEEP(x) sleep(x)
 #else
-void SLEEP (time_t s)
-{
-  while ((s = sleep (s)) > 0 && !binkd_exit && !poll_flag
-#ifdef HAVE_FORK
-         && !got_sighup && !got_sigchld
-#endif
-         );
-}
+#define SLEEP(x) sleep(x)
 #endif
 
 #if defined(HAVE_THREADS) && defined(OS2)
@@ -464,10 +466,7 @@ static int do_client(BINKD_CONFIG *config)
         threadsafe(--n_clients);
         PostSem(&eothread);
         Log (1, "cannot branch out");
-        unblocksig();
         SLEEP(1);
-        blocksig();
-        check_child(&n_clients);
       }
 #if !defined(DEBUGCHILD)
       else
@@ -481,27 +480,47 @@ static int do_client(BINKD_CONFIG *config)
     }
     else
     {
-      if (poll_flag)
-      {
-        if (n_clients <= 0 && q_not_empty (config) == 0)
-        {
-          Log (4, "the queue is empty, quitting...");
-          return -1;
-        }
-      } else
-        config->q_present = 0;
+      int need_sleep = config->rescan_delay;
+      time_t start_sleep = time(NULL), end_sleep;
+
       unblocksig();
-      SLEEP (config->rescan_delay);
-      blocksig();
+      while (need_sleep > 0 && !binkd_exit
+#if defined(HAVE_FORK) && !defined(HAVE_THREADS)
+             && !got_sighup
+#endif
+            )
+      {
+        check_child(&n_clients);
+        if (poll_flag && n_clients <= 0)
+        {
+          blocksig();
+          if (q_not_empty(config) == 0)
+          {
+            Log (4, "the queue is empty, quitting...");
+            return -1;
+          }
+          unblocksig();
+        }
+        SLEEP (need_sleep);
+        end_sleep = time(NULL);
+        if (end_sleep > start_sleep)
+          need_sleep -= (int)(end_sleep - start_sleep);
+        start_sleep = end_sleep;
+      }
       check_child(&n_clients);
+      blocksig();
+      if (!poll_flag)
+        config->q_present = 0;
     }
   }
   else
   {
+    /* This sleep can be interrupted by signal, it's OK */
     unblocksig();
-    SLEEP (config->call_delay);
-    blocksig();
     check_child(&n_clients);
+    SLEEP (config->call_delay);
+    check_child(&n_clients);
+    blocksig();
   }
 
   return 0;
