@@ -12,9 +12,17 @@
  */
 
 /*
- * $Id: ftnq.c,v 2.39.2.1 2013/02/03 07:29:03 gul Exp $
+ * $Id: ftnq.c,v 2.39.2.3 2014/08/09 15:17:42 gul Exp $
  *
  * $Log: ftnq.c,v $
+ * Revision 2.39.2.3  2014/08/09 15:17:42  gul
+ * Large files support on Win32 (backport from develop branch)
+ *
+ * Revision 2.39.2.2  2014/01/14 07:11:21  gul
+ * Fix possibly uninitialized variable:
+ * A node could be held to random time if it was an error during processing of .hld file
+ * (backport from default branch)
+ *
  * Revision 2.39.2.1  2013/02/03 07:29:03  gul
  * Possible segfault on after_session perl hook
  *
@@ -190,6 +198,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "sys.h"
 #include "readcfg.h"
 #include "ftnq.h"
 #include "ftnnode.h"
@@ -575,10 +584,9 @@ void process_hld (FTN_ADDR *fa, char *path, BINKD_CONFIG *config)
 
     if ((f = fopen (path, "r")) == NULL ||
 	fscanf (f, "%ld", &hold_until_tmp) != 1)
-    {
       node->hold_until = 0;
-    }
-    node->hold_until = (time_t)hold_until_tmp;
+    else
+      node->hold_until = (time_t)hold_until_tmp;
     if (f)
       fclose (f);
 
@@ -848,8 +856,8 @@ FTNQ *q_add_file (FTNQ *q, char *filename, FTN_ADDR *fa1, char flvr, char action
     q->sent = 0;
 
     if (type == 's')
-    { q->size = atol(argv[1]);
-      q->time = atol(argv[2]);
+    { q->size = (boff_t) strtoumax(argv[1], NULL, 10);
+      q->time = safe_atol(argv[2], NULL);
       strnzcpy (q->path, argv[0], MAXPATHLEN);
     }
     else
