@@ -12,9 +12,16 @@
  */
 
 /*
- * $Id: tools.c,v 2.75.2.2 2012/10/29 19:52:57 green Exp $
+ * $Id: tools.c,v 2.75.2.4 2014/08/20 06:12:38 gul Exp $
  *
  * $Log: tools.c,v $
+ * Revision 2.75.2.4  2014/08/20 06:12:38  gul
+ * Fixed 100% cpu load if called with poll flag,
+ * backport many fixes related to compilation on win32 and os/2.
+ *
+ * Revision 2.75.2.3  2014/08/09 15:17:44  gul
+ * Large files support on Win32 (backport from develop branch)
+ *
  * Revision 2.75.2.2  2012/10/29 19:52:57  green
  * Corrected Segfault in config error reporting on 64bit architectures
  *
@@ -335,10 +342,10 @@
 #include <syslog.h>
 #endif
 
+#include "sys.h"
 #include "readcfg.h"
 #include "common.h"
 #include "tools.h"
-#include "sys.h"
 #include "readdir.h"		       /* for [sys/]utime.h */
 #include "sem.h"
 #include "assert.h"
@@ -500,7 +507,6 @@ struct tm *safe_gmtime(time_t *t, struct tm *tm)
 #endif
 
 #ifdef WIN32
-#include <windows.h>
 
 static void stime_to_tm(const SYSTEMTIME *stime, struct tm *tm)
 {
@@ -1208,7 +1214,8 @@ long safe_atol(char *str, char **msg)
     }
   } else {
     errno = EINVAL;
-    *msg = "Invalid argument (NULL instead string)";
+    if (msg)
+      *msg = "Invalid argument (NULL instead string)";
   }
   return (long)ul;
 }
